The QuickSortPy library (by RapidDragon2612) is a working python implementation of the quick sort algorithm.
Quick sort is widely considered to be the fastest and most efficient sorting algorithm.

To use QuickSortPy, run:

import quicksortpy

And then use the quicksortpy.sort() function, with the argument of the array which is to be sorted:

quicksortpy.sort(example_array)

This modifies the original array, but also returns the array as an output which can be used like so:

sorted_array = quicksortpy.sort(original_array)
